@@ -1,17 +1,12 @@
+{-# LANGUAGE CPP, NoImplicitPrelude #-}
 module Data.Bool.Compat (
-   -- * Booleans
-   Bool(..),
-   -- ** Operations
-   (&&),
-   (||),
-   not,
-   otherwise,
-   bool,
-  ) where
+  module Base
+, bool
+) where
 
-import Data.Bool
+import Data.Bool as Base
 
-#if !MIN_VERSION_base(4,7,0)
+#if !(MIN_VERSION_base(4,7,0))
 -- | Case analysis for the 'Bool' type.
 -- @bool a b p@ evaluates to @a@ when @p@ is @False@, and evaluates to @b@
 -- when @p@ is @True@.
