@@ -1,17 +1,15 @@
+{-# LANGUAGE CPP, NoImplicitPrelude #-}
 {-# LANGUAGE CPP #-}
 module System.Exit.Compat (
-  ExitCode(..)
-, exitWith
-, exitFailure
-, exitSuccess
+  module Base
 , die
 ) where
 
-import System.Exit
+import System.Exit as Base
 
-#if !MIN_VERSION_base(4,8,0)
+#if !(MIN_VERSION_base(4,8,0))
 
-import Prelude
+import Prelude.Compat
 import System.IO
 
 -- | Write given error message to `stderr` and terminate with `exitFailure`.
